'use strict';

var expect = require('chai').expect,
    path = require('path'),
    _ = require('lodash'),
    gitCMD = require('../index');
    
describe('# Git Commit Markdown', function() {
    describe('- Commits as a JSON', function() {
        it('should show the commits as a JSON object', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                expect(_.isPlainObject(result.data)).to.be.true;
                expect(result.data).to.not.have.property('test');
                
                done();
            });
        });
        
        it.skip('should show the commits as a JSON object (sync)', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                markdown: true,
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                
                done();
            });
        });
    });
    describe('- Commits as a Markdown', function() {
        it('should show the commits as a Markdown string', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                //markdown: true,
                file: path.join(__dirname, '../CHANGELOG.md'),
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                
                done();
            });
        });
        
        it.skip('should show the commits as a Markdown string (sync)', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                //markdown: true,
                file: path.join(__dirname, '../CHANGELOG.md'),
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                
                done();
            });
        });
    });
    describe('- Commits saved to a file', function() {
        it('should write the commits into a file', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                //markdown: true,
                file: path.join(__dirname, '../CHANGELOG.md'),
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                
                done();
            });
        });
        
        it.skip('should write the commits into a file (sync)', function(done) {
            var opts = {
                remote: 'https://github.com/EastolfiWebDev/GitCommitMarkdown',
                fields: ['shortHash', 'subject', 'commitDate'],
                //markdown: true,
                file: path.join(__dirname, '../CHANGELOG.md'),
                ignoreIrrelevants: true,
                sort: true
            };
            
            gitCMD(opts, function(err, result) {
                expect(err).to.not.exist;
                expect(result.done).to.exist;
                
                expect(result.done).to.be.true;
                
                done();
            });
        });
    });
});